% WRV_Plot_3D_BrushCreek.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/05/26
% DATE MODIFIED:    2017/04/26
% VERSION:          v.2
%
% PURPOSE:  To construct 3D fault geometry of Brush Creek Fault at Wind River
% Valley
%
% PURPOSE OF MODIFICATION:  To update fault geometry based on lidar
% 
% INPUT: Surface points from mapped fault trace:
%            1) Brush_Creek_Fault_refined_surfacepoints.csv
%        intersection with Wind River Fault:
%            2) Brush_Creek_Fault_refined_intersection.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 1;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% brush creek fault %%

% local origin
xo = 0;
yo = 0;

% import data
% surface points
data = importdata('Brush_Creek_Fault_refined_surfacepoints.csv',',');
% lat = data.data(:,2);
% long = data.data(:,1);
% [x,y,utmzone] = deg2utm(lat,long);
x = data.data(:,1) - xo;
y = data.data(:,2) - yo;
z = zeros(numel(x),1);

% intersection
dataint = importdata('Brush_Creek_Fault_refined_intersection.csv',',');
xi = dataint.data(:,1);
yi = dataint.data(:,2);
xi = xi - xo;
yi = yi - yo;
zi = dataint.data(:,3);
% fit normal vector
if show_graph==1
    figure
end
clear c;clear n
c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
n = fitNormal(c, show_graph);

% rotate to j=0
theta = atan(-n(2)/n(1));
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
dx = 0;
dy = 0;
for i=1:numel(x)
    b = Rccw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end
for i=1:numel(xi)
    b = Rccw*[xi(i);yi(i)];
    xi(i) = b(1)+dx;yi(i) = b(2)+dy;
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [x;xi];c(:,2) = [y;yi];c(:,3) = [z;zi];
    n = fitNormal(c, show_graph);
end

I = find(x==xi(1));

% add fault nodes at depth
for i=1:numel(x)
    if i>33&&i<=35
        xd{i} = xi(1:3:19) - (x(I)-x(i));
        yd{i} = yi(1:3:19) - (y(I)-y(i));
        zd{i} = zi(1:3:19) - (z(I)-z(i));
    elseif i==36
        xd{i} = xi([1 5 9 14 19]) - (x(I)-x(i));
        yd{i} = yi([1 5 9 14 19]) - (y(I)-y(i));
        zd{i} = zi([1 5 9 14 19]) - (z(I)-z(i));
    elseif i==37
        xd{i} = xi([1 10 19]) - (x(I)-x(i));
        yd{i} = yi([1 10 19]) - (y(I)-y(i));
        zd{i} = zi([1 10 19]) - (z(I)-z(i));
    else
        xd{i} = xi - (x(I)-x(i));
        yd{i} = yi - (y(I)-y(i));
        zd{i} = zi - (z(I)-z(i));
    end
end
for i=1:numel(x)
    x = [x;xd{i}];
    y = [y;yd{i}];
    z = [z;zd{i}];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% fill out SW deep corner
for i=1:numel(xi)
    x = [x;(xi(i:numel(xi))-(x(10)-x(1)))];
    y = [y;(yi(i:numel(yi))-(y(10)-y(1))-100*i)];
    z = [z;zi(i:numel(zi))];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Trim off ends beyond surface trace
I = find(y>=y(1));
x = x(I);y = y(I);z = z(I);
I = find(y<max(y));
x = x(I);y = y(I);z = z(I);
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% Save vertical bounding lines
zi = [0;zi];
for i=1:numel(zi)
    I = find(z==zi(i));
    J = find(y(I)==min(y(I)));
    xs(i) = x(I(J));ys(i) = y(I(J));zs(i) = z(I(J));
    J = find(y(I)==max(y(I)));
    xn(i) = x(I(J));yn(i) = y(I(J));zn(i) = z(I(J));
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs';xn'];c(:,2) = [ys';yn'];c(:,3) = [zs';zn'];
    n = fitNormal(c, show_graph);
end

% add curvilinear tips
for i=1:20
    x = [x;xs(round(2+.1*i^2):numel(xs)-round(1+.1*i^2))'];
    y = [y;ys(round(2+.1*i^2):numel(ys)-round(1+.1*i^2))'-100*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
%     x = [x;xn(round(2+.1*i^2):numel(xn)-round(1+.1*i^2))'];
%     y = [y;yn(round(2+.1*i^2):numel(yn)-round(1+.1*i^2))'+100*i];
%     z = [z;zn(round(2+.1*i^2):numel(zn)-round(1+.1*i^2))'];
end
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% put xyz points for fault nodes into 3 column matrix
XYZbcf(:,1) = x;XYZbcf(:,2) = y;XYZbcf(:,3) = z;
for i=1:numel(XYZbcf(:,3))
    if XYZbcf(i,3)==0
        XYZbcf(i,3)=-1;
    end
end

% triangulate fault nodes
CON=Delaunay2_5D(XYZbcf);

% Rotate back
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
for i=1:numel(XYZbcf(:,1))
    b = Rcw*[XYZbcf(i,1)-dx;XYZbcf(i,2)-dy];
    XYZbcf(i,1) = b(1);XYZbcf(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZbcf(:,1),XYZbcf(:,2),XYZbcf(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('Brush Creek Fault','fontsize',12)
hold on

% plot fault triangulation
for i=1:numel(CON(:,1))
    plot3(XYZbcf([CON(i,:) CON(i,1)],1),XYZbcf([CON(i,:) CON(i,1)],2),XYZbcf([CON(i,:) CON(i,1)],3),'b-')
end

% correct polarity of triangulation
[tnbcf,nvecbcf] = PlotTriNormals(CON,XYZbcf,convention);

% Translate back to UTM
XYZbcf(:,1) = XYZbcf(:,1) + xo;
XYZbcf(:,2) = XYZbcf(:,2) + yo;