% WRV_Plot_3D_BunkerHill.m
%
% AUTHOR:           Michael W. Swyer
% DATE CREATED:     2015/08/28
% DATE MODIFIED:    2017/04/26
% VERSION:          v.2
%
% PURPOSE:  To construct 3D fault geometry of Bunker Hill Fault at Wind River
% Valley
%
% PURPOSE OF MODIFICATION:  To update fault geometry
% 
% INPUT: Surface points from mapped fault trace:
%       Bunker_Hill_Fault_refined_surfacepoints.csv
%
% OUTPUT: Position of fault nodes in UTM Zone 10N meters (XYZ-),
% triangulation of fault nodes (tn-), and unit normal vectors of fault element
% triangles (nvec-).
%
% NOTE:
%
% KEY functions written specifically for this modeling:
%
% Other related functions:
%       deg2utm.m
%       fitNormal.m
%       Delaunay2_5D.m
%       PlotTriNormals.m

clear all;close all

show_graph = 1;% Show graph of fit normal (0=no 1=yes)
f = 1;% smoothing factor (0 to 1)
convention = 'z-';% PlotTriNormals vector direction
%% bunker hill fault %%

% local origin
xo = 5.82e5;
yo = 5.074e6;

% import data
data = importdata('Bunker_Hill_Fault_refined_surfacepoints.csv',',');
x = data.data(:,1) - xo;
y = data.data(:,2) - yo;
z = -ones(numel(x),1);

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate to j=0
theta = atan((max(x)-min(x))/(max(y)-min(y)));
Rccw = [cos(theta) -sin(theta);sin(theta) cos(theta)];
dx = 500;
dy = 0;
for i=1:numel(x)
    b = Rccw*[x(i);y(i)];
    x(i) = b(1)+dx;y(i) = b(2)+dy;
end

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% project surface trace to depth
for i=1:32
    x(numel(x)+1:numel(x)+15) = x(1:15);
    y(numel(y)+1:numel(y)+15) = y(1:15);
    z(numel(z)+1:numel(z)+15) = -i*100;
end
for i=1:10
    x(numel(x)+1:numel(x)+2) = x(16:17);
    y(numel(y)+1:numel(y)+2) = y(16:17);
    z(numel(z)+1:numel(z)+2) = -i*320;
end
for i=1:5
    x(numel(x)+1) = x(18);
    y(numel(y)+1) = y(18);
    z(numel(z)+1) = -i*640;
end
for i=1:4
    x(numel(x)+1) = x(19);
    y(numel(y)+1) = y(19);
    z(numel(z)+1) = -i*800;
end
% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% find fault edges
q = unique(z);
for i=1:numel(q)
    I = find(z==q(i));
    J = find(y(I)==min(y(I)));
    xs(i) = x(I(J));ys(i) = y(I(J));zs(i) = z(I(J));
    J = find(y(I)==max(y(I)));
    xn(i) = x(I(J));yn(i) = y(I(J));zn(i) = z(I(J));
end
% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = [xs';xn'];c(:,2) = [ys';yn'];c(:,3) = [zs';zn'];
    n = fitNormal(c, show_graph);
end

I = find(ys<400);
d = xs(I);
clear xs;
xs = d;
clear d
d = ys(I);
clear ys;
ys = d;
clear d
d = zs(I);
clear zs;
zs = d;
clear d

I = find(yn>3400);
d = xn(I);
clear xn;
xn = d;
clear d
d = yn(I);
clear yn;
yn = d;
clear d
d = zn(I);
clear zn;
zn = d;
clear d

% add curvilinear fault tips
for i=1:12
    x = [x;xs(round(2+.1*i^2):numel(xs)-round(1+.1*i^2))'];
    y = [y;ys(round(2+.1*i^2):numel(ys)-round(1+.1*i^2))'-100*i];
    z = [z;zs(round(2+.1*i^2):numel(zs)-round(1+.1*i^2))'];
%     x = [x;xn(round(2+.3*i^2):numel(xn)-round(1+.3*i^2))'];
%     y = [y;yn(round(2+.3*i^2):numel(yn)-round(1+.3*i^2))'+800*i];
%     z = [z;zs(round(2+.3*i^2):numel(zs)-round(1+.3*i^2))'];
end

x = [x;xn(2:4)'];
y = [y;yn(2:4)'+800];
z = [z;zn(2:4)'];

% fit normal vector
if show_graph==1
    figure
    clear c;clear n
    c(:,1) = x;c(:,2) = y;c(:,3) = z;
    n = fitNormal(c, show_graph);
end

% rotate about y-axis
xsu = max(x);
x = x - xsu;
Rccw = [cos(-10*(pi/180)) -sin(-10*(pi/180));sin(-10*(pi/180)) cos(-10*(pi/180))];
for i=1:numel(x)
    b = Rccw*[x(i);z(i)];
    x(i) = b(1);z(i) = b(2);
end
x = x + xsu;

% put xyz points for fault nodes in a 3 column matrix
XYZbhf(:,1) = x;XYZbhf(:,2) = y;XYZbhf(:,3) = z;
for i=1:numel(XYZbhf(:,3))
    if XYZbhf(i,3)==0
        XYZbhf(i,3)=-1;
    end
end

% triangulate fault nodes
CON=Delaunay2_5D(XYZbhf);

% Rotate back
Rcw = [cos(theta) sin(theta);-sin(theta) cos(theta)];
for i=1:numel(XYZbhf(:,1))
    b = Rcw*[XYZbhf(i,1)-dx;XYZbhf(i,2)-dy];
    XYZbhf(i,1) = b(1);XYZbhf(i,2) = b(2);
end

% plot fault nodes
figure
plot3(XYZbhf(:,1),XYZbhf(:,2),XYZbhf(:,3),'ko');
xlabel('E-W(m)','fontsize',12)
ylabel('N-S(m)','fontsize',12)
axis equal;grid on
title('Bunker Hill Fault','fontsize',12)
hold on

% plot fault mesh
for i=1:numel(CON(:,1))
    plot3(XYZbhf([CON(i,:) CON(i,1)],1),XYZbhf([CON(i,:) CON(i,1)],2),XYZbhf([CON(i,:) CON(i,1)],3),'b-')
end

% correct polarity of triangulation
[tnbhf,nvecbhf] = PlotTriNormals(CON,XYZbhf,convention);

% Translate back to UTM
XYZbhf(:,1) = XYZbhf(:,1) + xo;
XYZbhf(:,2) = XYZbhf(:,2) + yo;