% MASTER_p3d_WRV_refined.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     5/18/2015
% DATE MODIFIED:    4/27/2017
% VERSION:          v.2
%
% PURPOSE:
%   Script to run poly3d, version from 1999, in c++ is slaved to matlab
%   for:
%   - Modeling the faults at Wind River Valley
%
% OBSERVATION GRIDS:
%      Areal grid: 2D
%           -Extent of WADGER thermal model for WRV with 2000 ft obs point
%           spacing converted to meters in UTM.
%          
% PURPOSE OF MODIFICATION: using less faults, and finer fault mesh and observation grids
% around the areas of interest for phase 2 of Washington play fairway
% analysis.
%
% INPUT: Fault nodes and connectivity in global coordinates NAD_1983_UTM_ZONE_10N
%       , Stress tensors for 200m and 3000m depths and focal mechanism observation
%       points in Microsoft Excel format named:
%           -Wind_River_Fault_refined.xls
%           -Bunker_Hill_Fault_refined.xls
%           -Bear_Creek_Fault_refined.xls
%           -Brush_Creek_Fault_refined.xls
%           -Shiperds_Fault_refined.xls
%           -StressTensorWRV200.csv
%           -StressTensorWRV3km.csv
% 
% OUTPUT: Poly 3D Input and Output files named:
%           -WindRiver200_AOIs.in
%           -WindRiver200_AOIs.out
%           -WindRiver2km_AOIs.in
%           -WindRiver2km_AOIs.out
%
% NOTE: 
% - Based on original files drafted by J. Ole Kaven
% 
% - Note specific paths to the folder containg p3d and to the folder
% containing this mfile are specified for running p3d and saving .in and
% .out files respectively
% 
% 
% KEY functions written specifically for this modeling
%
% Other related functions
% - Delaunay2_5D 
% - p3din_FAULT_func_v1
% - PlotTriNormals
% - p3doutputreader_v04
%
%

clear all, close all


%% 1. Define OBSERVATION GRID RANGES
% Generate observation grids in global coordinates.

% AREAL GRIDS: 2D

% User Coordinate Systems
% south aoi
x1o = 593617.1312;
x2o = 5061893.2130;
x3o = 0;
rot1 = 0;
rot2 = 0;
rot3 = 50.4422110742356;
CS_AOIsouth = [x1o, x2o, x3o, rot1, rot2, rot3, 123];% matrix used in p3din_FAULT_func_v1
% north aoi
x1o = 579541.62948;
x2o = 5071690.267;
x3o = 0;
rot1 = 0;
rot2 = 0;
rot3 = 0;
CS_AOInorth = [x1o, x2o, x3o, rot1, rot2, rot3, 123];% matrix used in p3din_FAULT_func_v1

% Extent of south AOI @ 200m depth
% min/max values  spacing at 200m depth
minx = 0;  % min value of x
maxx = 4000;  % max value of x
miny = 0;  % min value of y
maxy = 8000; % max value of y
minz = -200;  % min value of z
maxz = -200;  % max value of z    
npx  = 41; % number of points corresponding to inc in each dimension
npy  = 81; % see also function: linspace
npz  = 1;
OBSgridAOIsouth200m = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

% Extent of south AOI @ 2km depth
% min/max values  spacing at 200m depth
minx = 0;  % min value of x
maxx = 4000;  % max value of x
miny = 0;  % min value of y
maxy = 8000; % max value of y
minz = -2000;  % min value of z
maxz = -2000;  % max value of z    
npx  = 41; % number of points corresponding to inc in each dimension
npy  = 81; % see also function: linspace
npz  = 1;
OBSgridAOIsouth2km = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

% Extent of north AOI @ 200m depth
% min/max values  spacing at 200m depth
minx = 0;  % min value of x
maxx = 4000;  % max value of x
miny = 0;  % min value of y
maxy = 4000; % max value of y
minz = -200;  % min value of z
maxz = -200;  % max value of z    
npx  = 41; % number of points corresponding to inc in each dimension
npy  = 41; % see also function: linspace
npz  = 1;
OBSgridAOInorth200m = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1

% Extent of north AOI @ 2km depth
% min/max values  spacing at 200m depth
minx = 0;  % min value of x
maxx = 4000;  % max value of x
miny = 0;  % min value of y
maxy = 4000; % max value of y
minz = -2000;  % min value of z
maxz = -2000;  % max value of z    
npx  = 41; % number of points corresponding to inc in each dimension
npy  = 41; % see also function: linspace
npz  = 1;
OBSgridAOInorth2km = [minx miny minz maxx maxy maxz npx npy npz];% matrix used in p3din_FAULT_func_v1


%% 2. Define Boundary Conditions to run

% depth to water table(meters)
dw = 20;

% import stress tensor(s)
% 200m
Sigma200 = importdata('StressTensorWRV200.csv',',');
d = .2;% depth km
Pp200 = (9.733*(d-(dw/1000)));
Pf200 = Pp200*1000000;% fluid pressure used in poly3D
% 2000m
Sigma2km = importdata('StressTensorWRV2km.csv',',');
d = 2;% depth km
Pp2km = (9.733*(d-(dw/1000)));
Pf2km = Pp2km*1000000;% fluid pressure used in poly3D

% Elastic Properties for unconfined basalt at elevated temp (~450C) based
% on Schultz, 1993
nu = 0.25; % poisson's ratio
E = 57000000000; % Young's Modulus in Pa
   
    %% 3. IMPORT FAULTS
     
    % Wind River Fault deep
    XYZwrfd = xlsread('Wind_River_Fault_refined.xls','XYZwrfd','A2:C10000');
    tnwrfd = xlsread('Wind_River_Fault_refined.xls','tnwrfd','A1:C10000');
    
    % Wind River Fault shallow
    XYZwrfs = xlsread('Wind_River_Fault_refined.xls','XYZwrfs','A2:C10000');
    tnwrfs = xlsread('Wind_River_Fault_refined.xls','tnwrfs','A1:C10000');
    
    % Bunker Hill Fault
    XYZbhf = xlsread('Bunker_Hill_Fault_refined.xls','XYZbhf','A2:C10000');
    tnbhf = xlsread('Bunker_Hill_Fault_refined.xls','tnbhf','A1:C10000');
    
    % Bear Creek Fault
    XYZbcf = xlsread('Bear_Creek_Fault_refined.xls','XYZbcf','A2:C10000');
    tnbcf = xlsread('Bear_Creek_Fault_refined.xls','tnbcf','A1:C10000');
    
    % Brush Creek Fault
    XYZbrcf = xlsread('Brush_Creek_Fault_refined.xls','XYZbrcf','A2:C10000');
    tnbrcf = xlsread('Brush_Creek_Fault_refined.xls','tnbrcf','A1:C10000');
    
    % Shiperds Fault
    XYZsf = xlsread('Shiperds_Fault_refined.xls','XYZsf','A2:C10000');
    tnsf = xlsread('Shiperds_Fault_refined.xls','tnsf','A1:C10000');
    
    %% 4. RUN p3din_FAULT_v1.m to generate P3D input file and run P3D

tic
    
    filename = 'WindRiver200m_AOIs';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_200m(E,nu,Sigma200,Pf200,filename_in,XYZwrfd,XYZwrfs,XYZbhf,XYZbcf,XYZbrcf,XYZsf,tnwrfd,tnwrfs,tnbhf,tnbcf,tnbrcf,tnsf,CS_AOIsouth,CS_AOInorth,OBSgridAOIsouth200m,OBSgridAOInorth200m)
   
%         %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc

tic

    filename = 'WindRiver2km_AOIs';
    path_in = strcat('InputOutputFiles/');
    filename_in  = [path_in,filename,'.in'];
    
        % p3din_FAULT_v1
        p3din_FAULT_func_v1_WRV_2km(E,nu,Sigma2km,Pf2km,filename_in,XYZwrfd,XYZwrfs,XYZbhf,XYZbcf,XYZbrcf,XYZsf,tnwrfd,tnwrfs,tnbhf,tnbcf,tnbrcf,tnsf,CS_AOIsouth,CS_AOInorth,OBSgridAOIsouth2km,OBSgridAOInorth2km)
    
%         %%% Un-comment these lines to run Poly3D %%%
%         filename_out  = [path_in,filename,'.out'];
%         pcdloc = '/P3D/P3DinC1999/newpoly3d';
%         system([pcdloc,' -i ',filename_in,' -o ',filename_out])

toc