% WRV_PermeabilityModel_200m_AOIs.m
%
% AUTHOR:           Michael Swyer
% DATE CREATED:     8/3/2015
% DATE MODIFIED:    5/1/2017
% VERSION:          v.2
%
% PURPOSE:
%   Read Poly3D .out file and process data for permeability potential
%         
% PURPOSE OF MODIFICATION: using less faults, and finer fault mesh and observation grids
% around the areas of interest for phase 2 of Washington play fairway
% analysis. Also, combining Sigma3 and dilation tendency layers into
% "dilation" layer, and removing displacement layer. only four favorability
% layers instead of eight.
%
% INPUT: Poly3D output file
%           -WindRiver200m_AOIs.out
% 
% OUTPUT:
%   fault/stress model outputs:
%           -FAULT_GRID: x, y, z, slip tendency, displacement gradient(m/m)
%           -STRESS_GRID: x, y, z, maximum Coulomb shear stress(Pa),
%            dilation (sigma3(Pa) + dilation tendency)
%   Permeability potential layers:
%           -Fault2.sliptendency: x, y, z, slip tendency
%           -Fault2.displacementgradient: x, y, z, normalized displacement gradient
%           -Stress2.MaximumCoulombShearStress: x, y, z, normalized maximum Coulomb shear stress
%           -Stress2.dilation: x, y, z, normalized sigma 3 + dilation tendency
%
% NOTE: 
%
% KEY functions written specifically for this modeling
%
% Other related functions
% - p3doutputreader_v05
% - redblue

clear all;close all

filename = 'InputOutputFiles\WindRiver200m_AOIs.out';

out = p3doutputreader_v05(filename);
% Generates structured array including
%   FAULT OBJECTS
%   out.fault.xyz   = array of vertex locations
% 
%   out.fault.vert  = array of vertices
%                     [VERTNUM X1 X2 X3]
% 
%   out.fault.disp  = cell array contain displacements for each fault obj
%                     [ELT X1C X2C X3C B1 U1(+) U1(-) B2 U2(+) U2(-) B3 U3(+)]
%                     ELT = element number, for use in tri
%                     X1C, X2C, X3C = element centroid coordinates
%                     B1, B2, B3 are the burgers vectos components as
%                       (strike,dip,normal)
%                     Ui(+), Ui(-) = relative displacment at centroid
%
%   out.fault.tract = cell array contain tractions for each fault obj
%                     [ELT X1C X2C X3C T1 T2 T3]
%                     T1,T2,T3 are the traction components
%                       (strike,dip,normal)
%   out.fault.name  = cell array contain displacements for each fault obj
% 
%
%   OBSERVATION GRID
%   out.obs.xyz     = array containing the obs grid pts [X1,X2,X3]
%
%   out.obs.disp    = array containing displacements at obs pts
%                     [X1 X2 X3 U1 U2 U3]
%                     U1,U2,U3 = components of the displacement vector
%                     
%   out.obs.pstress = array containing principal stress and principal
%                     stress direcitons at obs pts
%                     [X1 X2 X3 N1 N2 N3 SIG1 N1 N2 N3 SIG2 N1 N2 N3 SIG3]
%                     SIG1,2,3 = principal stress components (tensoral
%                     convention) at each observation point
%                     N1,N2,N3 = principal stress direction vectors for the
%                       following principal stress in the array)
%
%   out.obs.stress  = array contain 
%                     [X1 X2 X3 SIG11 SIG22 SIG33 SIG12 SIG23 SIG13]
%                     SIG11,22,33,12,23,13 = stress tensor component at
%                     each observation point

% % fix N-S resolution of northen AOI because of typo (npy=81 like south AOI
% % instead of 41) only for 200m layer of Wind River. Remove for future model
% % runs when the typo is fixed.
% I = [5071690.267:100:(5071690.267+4000)];
% for i=1:numel(I)
%     J = find(out.obs.pstress{2}(:,2)==I(i));
%     if i==1
%         K = J;
%     else
%         K = [K J];
%     end
% end
% dummy = out.obs.pstress{2}(K,:);
% clear out.obs.pstress{2}
% out.obs.pstress{2} = dummy;

%% Remote Stress Tensor and Principal Stresses
Sigma200 = importdata('StressTensorWRV200.csv',',');
[V,PS200] = eig(Sigma200);% PS200 = eigenvalues as principal stresses

%% Slip/Dilation Tendency/Displacement/Displacement Gradient

%%% 200m %%%

% Wind River Fault

nvecwrfs = xlsread('Wind_River_Fault_refined.xls','nvecwrfs','A2:C6000');
I = find(out.fault.disp{1,2}(:,4)<-230&out.fault.disp{1,2}(:,4)>-295);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,2}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecwrfs(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecwrfs(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STwrf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTwrf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispwrf(i,1) = (out.fault.disp{1,2}(I(i),5)^2 + out.fault.disp{1,2}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STwrf = STwrf(I,1);
DTwrf = DTwrf(I,1);
Dispwrf = Dispwrf(I,1);
% Displacement Gradients
for i=2:length(I)
    if i==1
        dg(i,1) = Dispwrf(i)/80;
    else
        dg(i-1,1) = abs(Dispwrf(i)-Dispwrf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i) = Dispwrf(i)/80;
for i=1:(length(dg)-1)
    DGwrf(i,1) = mean([dg(i) dg(i+1)]);
end
d = DGwrf;
clear DGwrf
DGwrf(1,1) = d(1);
DGwrf(2:(length(d)+1),1) = d;
DGwrf((length(DGwrf)+1),1) = d(length(d));
% Find observation points closest to fault
clear Dobs;clear J
n=1;
for i=1:length(I)
    for j=1:length(out.obs.pstress{1})
        Dobs(j) = ((XYZ(i,1)-out.obs.pstress{1}(j,1))^2 + (XYZ(i,2)-out.obs.pstress{1}(j,2))^2)^.5;
    end
    if min(Dobs)<=100
        J(n,1) = find(Dobs==min(Dobs));
        J(n,2) = n;
        n=n+1;
    else
    end
end
% Find unique observation points and closest element center
Lwrf(:,1) = unique(J(:,1));
for i=1:length(Lwrf)
    I = find(J(:,1)==Lwrf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.pstress{1}(Lwrf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.pstress{1}(Lwrf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lwrf(i,2) = J(I(K),2);
end


% Bunker Hill Fault
nvecbhf = xlsread('Bunker_Hill_Fault_refined.xls','nvecbhf','A2:C6000');
I = find(out.fault.disp{1,3}(:,4)<-230&out.fault.disp{1,3}(:,4)>-295);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,3}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbhf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbhf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbhf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbhf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbhf(i,1) = (out.fault.disp{1,3}(I(i),5)^2 + out.fault.disp{1,3}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbhf = STbhf(I,1);
DTbhf = DTbhf(I,1);
Dispbhf = Dispbhf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbhf(i)/33;
    else
        dg(i,1) = abs(Dispbhf(i)-Dispbhf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
        dx(i) = (((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbhf(i)/33;
for i=1:length(I)
    DGbhf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
n=1;
for i=1:length(I)
    for j=1:length(out.obs.pstress{2})
        Dobs(j) = ((XYZ(i,1)-out.obs.pstress{2}(j,1))^2 + (XYZ(i,2)-out.obs.pstress{2}(j,2))^2)^.5;
    end
%     J(i,1) = find(Dobs==min(Dobs));
%     J(i,2) = i;
    if min(Dobs)<=100
        J(n,1) = find(Dobs==min(Dobs));
        J(n,2) = n;
        n=n+1;
    else
    end
end
% Find unique observation points and closest element center
Lbhf(:,1) = unique(J(:,1));
for i=1:length(Lbhf)
    I = find(J(:,1)==Lbhf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.pstress{2}(Lbhf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.pstress{2}(Lbhf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbhf(i,2) = J(I(K),2);
end


% Bear Creek Fault
nvecbcf = xlsread('Bear_Creek_Fault_refined.xls','nvecbcf','A2:C6000');
I = find(out.fault.disp{1,4}(:,4)<230&out.fault.disp{1,4}(:,4)>-295);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,4}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbcf(i,1) = (out.fault.disp{1,4}(I(i),5)^2 + out.fault.disp{1,4}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbcf = STbcf(I,1);
DTbcf = DTbcf(I,1);
Dispbcf = Dispbcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbcf(i)/50;
    else
        dg(i,1) = abs(Dispbcf(i)-Dispbcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbcf(i)/50;
for i=1:length(I)
    DGbcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
n=1;
for i=1:length(I)
    for j=1:length(out.obs.pstress{1})
        Dobs(j) = ((XYZ(i,1)-out.obs.pstress{1}(j,1))^2 + (XYZ(i,2)-out.obs.pstress{1}(j,2))^2)^.5;
    end
    if min(Dobs)<=100
        J(n,1) = find(Dobs==min(Dobs));
        J(n,2) = n;
        n=n+1;
    else
    end
end
% Find unique observation points and closest element center
Lbcf(:,1) = unique(J(:,1));
for i=1:length(Lbcf)
    I = find(J(:,1)==Lbcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.pstress{1}(Lbcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.pstress{1}(Lbcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbcf(i,2) = J(I(K),2);
end


% Brush Creek Fault
nvecbrcf = xlsread('Brush_Creek_Fault_refined.xls','nvecbrcf','A2:C6000');
I = find(out.fault.disp{1,5}(:,4)<-230&out.fault.disp{1,5}(:,4)>-295);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,5}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecbrcf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecbrcf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STbrcf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTbrcf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispbrcf(i,1) = (out.fault.disp{1,5}(I(i),5)^2 + out.fault.disp{1,5}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STbrcf = STbrcf(I,1);
DTbrcf = DTbrcf(I,1);
Dispbrcf = Dispbrcf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispbrcf(i)/50;
    else
        dg(i,1) = abs(Dispbrcf(i)-Dispbrcf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispbrcf(i)/50;
for i=1:length(I)
    DGbrcf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
n=1;
for i=1:length(I)
    for j=1:length(out.obs.pstress{1})
        Dobs(j) = ((XYZ(i,1)-out.obs.pstress{1}(j,1))^2 + (XYZ(i,2)-out.obs.pstress{1}(j,2))^2)^.5;
    end
    if min(Dobs)<=100
        J(n,1) = find(Dobs==min(Dobs));
        J(n,2) = n;
        n=n+1;
    else
    end
end
% Find unique observation points and closest element center
Lbrcf(:,1) = unique(J(:,1));
for i=1:length(Lbrcf)
    I = find(J(:,1)==Lbrcf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.pstress{1}(Lbrcf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.pstress{1}(Lbrcf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lbrcf(i,2) = J(I(K),2);
end


% Shiperds Fault
nvecsf = xlsread('Shiperds_Fault_refined.xls','nvecsf','A2:C6000');
I = find(out.fault.disp{1,6}(:,4)<-230&out.fault.disp{1,6}(:,4)>-295);
% Tractions
clear XYZ
clear T
clear Tn
clear Tmag
clear DC
clear theta
clear Ts
for i=1:length(I)
    XYZ(i,:) = out.fault.disp{1,6}(I(i),2:4);% XYZ points
    T(i,:) = Sigma200*nvecsf(I(i),:)';% Tractions
    Tn(i,1) = -T(i,:)*nvecsf(I(i),:)';% Normal Tractions
    Tmag(i,1) = (T(i,1)^2 + T(i,2)^2 + T(i,3)^2)^(1/2);% Traction Magnitudes
    DC(i,1) = Tn(i,1)/Tmag(i,1);% Direction Cosines
    theta(i,1) = acos(DC(i,1));% Traction angle from normal vector
    Ts(i,1) = Tmag(i,1)*sin(theta(i,1));% Shear Tractions
    STsf(i,1) = Ts(i,1)/Tn(i,1);% Slip Tendencies
    DTsf(i,1) = ((-PS200(1,1))-(Tn(i,1)))/((-PS200(1,1))-(-PS200(3,3)));% Dilation Tendencies
    Dispsf(i,1) = (out.fault.disp{1,6}(I(i),5)^2 + out.fault.disp{1,6}(I(i),8)^2)^.5;% Displacements
end
% Sort elements from south to north
[ys,I] = sort(XYZ(:,2));
XYZ = XYZ(I,:);
STsf = STsf(I,1);
DTsf = DTsf(I,1);
Dispsf = Dispsf(I,1);
% Displacement Gradientws
for i=1:length(I)
    if i==1
        dg(i,1) = Dispsf(i)/50;
    else
        dg(i,1) = abs(Dispsf(i)-Dispsf(i-1))/(((XYZ(i,1)-XYZ(i-1,1))^2 + (XYZ(i,2)-XYZ(i-1,2))^2 + (XYZ(i,3)-XYZ(i-1,3))^2)^.5);
    end
end
dg(i+1) = Dispsf(i)/50;
for i=1:length(I)
    DGsf(i,1) = mean([dg(i) dg(i+1)]);
end
% Find observation points closest to fault
clear Dobs;clear J
n=1;
for i=1:length(I)
    for j=1:length(out.obs.pstress{1})
        Dobs(j) = ((XYZ(i,1)-out.obs.pstress{1}(j,1))^2 + (XYZ(i,2)-out.obs.pstress{1}(j,2))^2)^.5;
    end
    if min(Dobs)<=100
        J(n,1) = find(Dobs==min(Dobs));
        J(n,2) = n;
        n=n+1;
    else
    end
end
% Find unique observation points and closest element center
Lsf(:,1) = unique(J(:,1));
for i=1:length(Lsf)
    I = find(J(:,1)==Lsf(i));
    clear Dobs
    for j=1:length(I)
        Dobs(j) = ((XYZ(J(I(j),2),1)-out.obs.pstress{1}(Lsf(i),1))^2 + (XYZ(J(I(j),2),2)-out.obs.pstress{1}(Lsf(i),2))^2)^.5;
    end
    K = find(Dobs==min(Dobs));
    Lsf(i,2) = J(I(K),2);
end


%% combine fault layers south AOI
L_s = [Lwrf;Lbcf;Lbrcf;Lsf];
STall = [STwrf(Lwrf(:,2));STbcf(Lbcf(:,2));STbrcf(Lbrcf(:,2));STsf(Lsf(:,2))];
DTall = [DTwrf(Lwrf(:,2));DTbcf(Lbcf(:,2));DTbrcf(Lbrcf(:,2));DTsf(Lsf(:,2))];
DGall = [DGwrf(Lwrf(:,2));DGbcf(Lbcf(:,2));DGbrcf(Lbrcf(:,2));DGsf(Lsf(:,2))];

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
FAULT_GRID_south(:,1:3) = out.obs.pstress{1}(:,1:3);
for i=1:length(L_s)
        FAULT_GRID_south(L_s(i,1),4) = STall(i);
        FAULT_GRID_south(L_s(i,1),5) = DTall(i);
        FAULT_GRID_south(L_s(i,1),6) = DGall(i);
end

I = find(FAULT_GRID_south(:,6)==max(FAULT_GRID_south(:,6)));
FAULT_GRID_south(I,6)=4.495e-5;

%% Combine Stress layers for South AOI

% calculate Sc and S3
for i=1:length(out.obs.pstress{1})
    Sc_south(i,1) = (((-out.obs.pstress{1}(i,15))-(-out.obs.pstress{1}(i,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress{1}(i,15))+(-out.obs.pstress{1}(i,7)))/2);
    S3_south(i,1) = (-out.obs.pstress{1}(i,7));
    if find(L_s(:,1)==i)
        Sc_south(i,1) = 0;
        S3_south(i,1) = 0;
    end
end

% extract stress values to compute means and standard deviations
k=1;
clear ScReal
clear S3Real
for i=1:length(Sc_south)
    if isnan(Sc_south(i))
    else
        ScReal(k,1) = Sc_south(i);
        S3Real(k,1) = S3_south(i);
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean_south = mean(ScReal);
SigSc_south = std(ScReal);
% S3
S3mean_south = mean(S3Real);
SigS3_south = std(S3Real);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID_south(:,1:3) = out.obs.pstress{1}(:,1:3);
STRESS_GRID_south(:,4) = Sc_south;
STRESS_GRID_south(:,5) = S3_south;

%% Permeability Model Layer Normalization south AOI

% Fault Layers
% no normalization needed for slip/dilation tendency (0-1)
Fault.south.sliptendency(:,1:3) = FAULT_GRID_south(:,1:3);
Fault.south.sliptendency(:,4) = FAULT_GRID_south(:,4);
Fault.south.dilationtendency(:,1:3) = FAULT_GRID_south(:,1:3);
Fault.south.dilationtendency(:,4) = FAULT_GRID_south(:,5);
% displacement gradient
Fault.south.displacementgradient(:,1:3) = FAULT_GRID_south(:,1:3);
Fault.south.displacementgradient(:,4) = FAULT_GRID_south(:,6)/max(FAULT_GRID_south(:,6));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 3;% # of standard deviations
Stress.south.MaximumCoulombShearStress(:,1:3) = STRESS_GRID_south(:,1:3);
Stress.south.MaximumCoulombShearStress(:,4) = (STRESS_GRID_south(:,4)-(Scmean_south-nsd*SigSc_south))/(2*nsd*SigSc_south);
I = find(Stress.south.MaximumCoulombShearStress(:,4)<0);
Stress.south.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.south.MaximumCoulombShearStress(:,4)>1);
Stress.south.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L_s)
    Stress.south.MaximumCoulombShearStress(L_s(i,1),4) = 0;
end

% Inverse S3 values by adding 2*mean to negative values
nsd = 3;% # of standard deviations
Stress.south.Sigma3(:,1:3) = STRESS_GRID_south(:,1:3);
Stress.south.Sigma3(:,4) = -STRESS_GRID_south(:,5);
Stress.south.Sigma3(:,4) = (Stress.south.Sigma3(:,4)-(-S3mean_south-nsd*SigS3_south))/(2*nsd*SigS3_south);
I = find(Stress.south.Sigma3(:,4)<0);
Stress.south.Sigma3(I,4) = 0;
I = find(Stress.south.Sigma3(:,4)>1);
Stress.south.Sigma3(I,4) = 1;
for i=1:length(L_s)
    Stress.south.Sigma3(L_s(i,1),4) = 0;
end


% new favorability layers
Fault2.south.sliptendency = Fault.south.sliptendency;
Fault2.south.slipgradient = Fault.south.displacementgradient;
Stress2.south.shear = Stress.south.MaximumCoulombShearStress;
Stress2.south.dilation(:,1:3) = STRESS_GRID_south(:,1:3);
Stress2.south.dilation(:,4) = Stress.south.Sigma3(:,4) + Fault.south.dilationtendency(:,4);

clear STall
clear DTall
clear DGall
clear ScReal
clear S3Real

%% combine fault layers north AOI
L_n = [Lbhf];
STall = [STbhf(Lbhf(:,2))];
DTall = [DTbhf(Lbhf(:,2))];
DGall = [DGbhf(Lbhf(:,2))];

% FAULT_GRID --> X,Y,Z,slip tendency,dilation tendency,displacement gradient
FAULT_GRID_north(:,1:3) = out.obs.pstress{2}(:,1:3);
for i=1:length(L_n)
        FAULT_GRID_north(L_n(i,1),4) = STall(i);
        FAULT_GRID_north(L_n(i,1),5) = DTall(i);
        FAULT_GRID_north(L_n(i,1),6) = DGall(i);
end

I = find(FAULT_GRID_north(:,6)==max(FAULT_GRID_north(:,6)));
FAULT_GRID_north(I,6) = 3e-5;

%% Combine Stress layers for north AOI

% calculate Sc and S3
for i=1:length(out.obs.pstress{2})
    Sc_north(i,1) = (((-out.obs.pstress{2}(i,15))-(-out.obs.pstress{2}(i,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress{2}(i,15))+(-out.obs.pstress{2}(i,7)))/2);
    S3_north(i,1) = (-out.obs.pstress{2}(i,7));
    if find(L_n(:,1)==i)
        Sc_north(i,1) = 0;
        S3_north(i,1) = 0;
    end
end

% extract stress values to compute means and standard deviations
k=1;
clear ScReal
clear S3Real
for i=1:length(Sc_north)
    if isnan(Sc_north(i))
    else
        ScReal(k,1) = Sc_north(i);
        S3Real(k,1) = S3_north(i);
        k=k+1;
    end
end

% Mean and Standard Deviation
% Sc
Scmean_north = mean(ScReal);
SigSc_north = std(ScReal);
% S3
S3mean_north = mean(S3Real);
SigS3_north = std(S3Real);

% STRESS_GRID --> X,Y,Z,maximum Coulomb shear stress,Shmin
STRESS_GRID_north(:,1:3) = out.obs.pstress{2}(:,1:3);
STRESS_GRID_north(:,4) = Sc_north;
STRESS_GRID_north(:,5) = S3_north;

%% Permeability Model Layer Normalization north AOI

% Fault Layers
% no normalization needed for slip/dilation tendency (0-1)
Fault.north.sliptendency(:,1:3) = FAULT_GRID_north(:,1:3);
Fault.north.sliptendency(:,4) = FAULT_GRID_north(:,4);
Fault.north.dilationtendency(:,1:3) = FAULT_GRID_north(:,1:3);
Fault.north.dilationtendency(:,4) = FAULT_GRID_north(:,5);
% displacement gradient
Fault.north.displacementgradient(:,1:3) = FAULT_GRID_north(:,1:3);
Fault.north.displacementgradient(:,4) = FAULT_GRID_north(:,6)/max(FAULT_GRID_north(:,6));

% Stress Layers
% normalization between +/- X standard deviations
nsd = 3;% # of standard deviations
Stress.north.MaximumCoulombShearStress(:,1:3) = STRESS_GRID_north(:,1:3);
Stress.north.MaximumCoulombShearStress(:,4) = (STRESS_GRID_north(:,4)-(Scmean_north-nsd*SigSc_north))/(2*nsd*SigSc_north);
I = find(Stress.north.MaximumCoulombShearStress(:,4)<0);
Stress.north.MaximumCoulombShearStress(I,4) = 0;
I = find(Stress.north.MaximumCoulombShearStress(:,4)>1);
Stress.north.MaximumCoulombShearStress(I,4) = 1;
for i=1:length(L_n)
    Stress.north.MaximumCoulombShearStress(L_n(i,1),4) = 0;
end

% Inverse S3 values by adding 2*mean to negative values
nsd = 3;% # of standard deviations
Stress.north.Sigma3(:,1:3) = STRESS_GRID_north(:,1:3);
Stress.north.Sigma3(:,4) = -STRESS_GRID_north(:,5);
Stress.north.Sigma3(:,4) = (Stress.north.Sigma3(:,4)-(-S3mean_north-nsd*SigS3_north))/(2*nsd*SigS3_north);
I = find(Stress.north.Sigma3(:,4)<0);
Stress.north.Sigma3(I,4) = 0;
I = find(Stress.north.Sigma3(:,4)>1);
Stress.north.Sigma3(I,4) = 1;
for i=1:length(L_n)
    Stress.north.Sigma3(L_n(i,1),4) = 0;
end


% new favorability layers
Fault2.north.sliptendency = Fault.north.sliptendency;
Fault2.north.slipgradient = Fault.north.displacementgradient;
Stress2.north.shearstress = Stress.north.MaximumCoulombShearStress;
Stress2.north.dilation(:,1:3) = STRESS_GRID_north(:,1:3);
Stress2.north.dilation(:,4) = Stress.north.Sigma3(:,4) + Fault.north.dilationtendency(:,4);

clear STall
clear DTall
clear DGall
clear ScReal
clear S3Real

%% FIGURES

% south AOI
figure
plot([1:numel(Sc_south)],Sc_south,'k-');ylabel('Sc')
hold on
plot([0 length(out.obs.pstress{1})],[Scmean_south+nsd*SigSc_south Scmean_south+nsd*SigSc_south])
plot([0 length(out.obs.pstress{1})],[Scmean_south-nsd*SigSc_south Scmean_south-nsd*SigSc_south])
title('south AOI');
figure
plot([1:numel(S3_south)],S3_south,'k-');ylabel('Shmin')
hold on
plot([0 length(out.obs.pstress{1})],[S3mean_south+nsd*SigS3_south S3mean_south+nsd*SigS3_south])
plot([0 length(out.obs.pstress{1})],[S3mean_south-nsd*SigS3_south S3mean_south-nsd*SigS3_south])
title('south AOI');

figure
plot([1:numel(Stress.south.MaximumCoulombShearStress(:,4))],Stress.south.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
title('south AOI');
figure
plot([1:numel(Stress.south.Sigma3(:,4))],Stress.south.Sigma3(:,4),'k.');ylabel('Shmin favorability')
title('south AOI');

% north AOI
figure
plot([1:numel(Sc_north)],Sc_north,'k-');ylabel('Sc')
hold on
plot([0 length(out.obs.pstress{2})],[Scmean_north+nsd*SigSc_north Scmean_north+nsd*SigSc_north])
plot([0 length(out.obs.pstress{2})],[Scmean_north-nsd*SigSc_north Scmean_north-nsd*SigSc_north])
title('north AOI');
figure
plot([1:numel(S3_north)],S3_north,'k-');ylabel('Shmin')
hold on
plot([0 length(out.obs.pstress{2})],[S3mean_north+nsd*SigS3_north S3mean_north+nsd*SigS3_north])
plot([0 length(out.obs.pstress{2})],[S3mean_north-nsd*SigS3_north S3mean_north-nsd*SigS3_north])
title('north AOI');

figure
plot([1:numel(Stress.south.MaximumCoulombShearStress(:,4))],Stress.south.MaximumCoulombShearStress(:,4),'k.');ylabel('Sc favorability')
title('north AOI');
figure
plot([1:numel(Stress.south.Sigma3(:,4))],Stress.south.Sigma3(:,4),'k.');ylabel('Shmin favorability')
title('north AOI');

% grid data for contour plots
% south AOI
npx = 41;
npy = 81;
for j=0:(npy-1)
for i=0:(npx-1)
    X_s(1+i,1+j) = out.obs.pstress{1}((1+i)+npx*j,1);
    Y_s(1+i,1+j) = out.obs.pstress{1}((1+i)+npx*j,2);
    ScXY_s(1+i,1+j) = ((((-out.obs.pstress{1}((1+i)+npx*j,15))-(-out.obs.pstress{1}((1+i)+npx*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress{1}((1+i)+npx*j,15))+(-out.obs.pstress{1}((1+i)+npx*j,7)))/2))/1000000;
    S3XY_s(1+i,1+j) = (-out.obs.pstress{1}((1+i)+npx*j,7))/1000000;
    meanstressXY_s(1+i,1+j) = ((-out.obs.pstress{1}((1+i)+npx*j,7))+(-out.obs.pstress{1}((1+i)+npx*j,15)))/2/1000000;
    STXY_s(1+i,1+j) = FAULT_GRID_south((1+i)+npx*j,4);
    DTXY_s(1+i,1+j) = FAULT_GRID_south((1+i)+npx*j,5);
    DGXY_s(1+i,1+j) = FAULT_GRID_south((1+i)+npx*j,6);
    if find(L_s(:,1)==((1+i)+npx*j))
        ScXY_s(1+i,1+j) = NaN;
        S3XY_s(1+i,1+j) = NaN;
    end
end
end

% grid data for contour plots
% north AOI
npx = 41;
npy = 41;
for j=0:(npy-1)
for i=0:(npx-1)
    X_n(1+i,1+j) = out.obs.pstress{2}((1+i)+npx*j,1);
    Y_n(1+i,1+j) = out.obs.pstress{2}((1+i)+npx*j,2);
    ScXY_n(1+i,1+j) = ((((-out.obs.pstress{2}((1+i)+npx*j,15))-(-out.obs.pstress{2}((1+i)+npx*j,7)))/2)*(1+.6^2)^.5 - .6*(((-out.obs.pstress{2}((1+i)+npx*j,15))+(-out.obs.pstress{2}((1+i)+npx*j,7)))/2))/1000000;
    S3XY_n(1+i,1+j) = (-out.obs.pstress{2}((1+i)+npx*j,7))/1000000;
    meanstressXY_n(1+i,1+j) = ((-out.obs.pstress{2}((1+i)+npx*j,7))+(-out.obs.pstress{2}((1+i)+npx*j,15)))/2/1000000;
    STXY_n(1+i,1+j) = FAULT_GRID_north((1+i)+npx*j,4);
    DTXY_n(1+i,1+j) = FAULT_GRID_north((1+i)+npx*j,5);
    DGXY_n(1+i,1+j) = FAULT_GRID_north((1+i)+npx*j,6);
    if find(L_n(:,1)==((1+i)+npx*j))
        ScXY_n(1+i,1+j) = NaN;
        S3XY_n(1+i,1+j) = NaN;
    end
end
end

% Sc south AOI
clear Vm
Vm = [(Scmean_south-nsd*SigSc_south)/1000000:.1:(Scmean_south+nsd*SigSc_south)/1000000];
figure
contourf(X_s,Y_s,ScXY_s,Vm)
hold on
contour(X_s,Y_s,ScXY_s,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sc(MPa)','Fontsize',14);
caxis([(Scmean_south-nsd*SigSc_south)/1000000 (Scmean_south+nsd*SigSc_south)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('south AOI')
% Sc north AOI
clear Vm
Vm = [(Scmean_north-nsd*SigSc_north)/1000000:.1:(Scmean_north+nsd*SigSc_north)/1000000];
figure
contourf(X_n,Y_n,ScXY_n,Vm)
hold on
contour(X_n,Y_n,ScXY_n,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sc(MPa)','Fontsize',14);
caxis([(Scmean_north-nsd*SigSc_north)/1000000 (Scmean_north+nsd*SigSc_north)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('north AOI')

% S3 south AOI
clear Vm
Vm = [(S3mean_south-nsd*SigS3_south)/1000000:.1:(S3mean_south+nsd*SigS3_south)/1000000];
figure
contourf(X_s,Y_s,S3XY_s,Vm)
hold on
contour(X_s,Y_s,S3XY_s,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3(MPa)','Fontsize',14);
caxis([(S3mean_south-nsd*SigS3_south)/1000000 (S3mean_south+nsd*SigS3_south)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('south AOI')
% S3 north AOI
clear Vm
Vm = [(S3mean_north-nsd*SigS3_north)/1000000:.1:(S3mean_north+nsd*SigS3_north)/1000000];
figure
contourf(X_n,Y_n,S3XY_n,Vm)
hold on
contour(X_n,Y_n,S3XY_n,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Sigma3(MPa)','Fontsize',14);
caxis([(S3mean_north-nsd*SigS3_north)/1000000 (S3mean_north+nsd*SigS3_north)/1000000]);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('north AOI')

% slip tendency south AOI
figure
contourf(X_s,Y_s,STXY_s)
hold on
contour(X_s,Y_s,STXY_s)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('south AOI')
% slip tendency north AOI
figure
contourf(X_n,Y_n,STXY_n)
hold on
contour(X_n,Y_n,STXY_n)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('north AOI')

% dilation tendency south AOI
figure
contourf(X_s,Y_s,DTXY_s)
hold on
contour(X_s,Y_s,DTXY_s)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('south AOI')
% dilation tendency north AOI
figure
contourf(X_n,Y_n,DTXY_n)
hold on
contour(X_n,Y_n,DTXY_n)
c=colorbar;
set(get(c,'ylabel'),'String','Dilation Tendency','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
title('north AOI')

% displacement gradient south AOI
figure
clear Vm
Vm = [0:max(max(DGXY_s))/100:max(max(DGXY_s))];
contourf(X_s,Y_s,DGXY_s,Vm)
hold on
contour(X_s,Y_s,DGXY_s,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Gradient(m/m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)
% displacement gradient north AOI
figure
clear Vm
Vm = [0:max(max(DGXY_n))/100:max(max(DGXY_n))];
contourf(X_n,Y_n,DGXY_n,Vm)
hold on
contour(X_n,Y_n,DGXY_n,Vm)
c=colorbar;
set(get(c,'ylabel'),'String','Slip Gradient(m/m)','Fontsize',14);
colormap(redblue);
axis equal
xlabel('easting(m)','fontsize',12)
ylabel('northing(m)','fontsize',12)

